[![PyPI - Version](https://img.shields.io/pypi/v/stagpy)](https://pypi.org/project/stagpy/)
[![DOI on zenodo](https://zenodo.org/badge/DOI/10.5281/zenodo.5512348.svg)](https://doi.org/10.5281/zenodo.5512348)

StagPy
======

StagPy is a command line tool to process the output files of your StagYY
simulations and produce high-quality figures.

This command line tool is built around a generic interface that allows you to
access StagYY output data directly in a Python script.

You can install StagPy from the [Python Package
Index](https://pypi.org/project/stagpy/).
See the [full documentation](https://stagpython.github.io/StagPy/) for more
information.

If StagPy has been useful to your research, please consider citing the project
as:

> Adrien Morison, Martina Ulvrova, Stephane Labrosse, & contributors. (2021).
StagPython/StagPy. Zenodo. https://doi.org/10.5281/zenodo.5512348

or a specific version with the relevant DOI (e.g. for v0.15.0):

> Adrien Morison, Martina Ulvrova, Stephane Labrosse, & contributors. (2021).
StagPython/StagPy (v0.15.0). Zenodo. https://doi.org/10.5281/zenodo.5512349
